#include <fstream>
#include <string>
#include "image_io.h"
#include "rasterize_triangles.h"

int main(int argc, char** argv)
{
   for(int i=1; i<argc; ++i){
      std::ifstream input(argv[i]);
      if(!input){
         std::cout<<"error opening file "<<argv[i]<<std::endl;
         continue;
      }
      std::cout<<argv[i]<<std::endl;
      // name of output image
      std::string image_filename;
      input>>image_filename;
      std::cout<<" - output image: "<<image_filename<<std::endl;
      // dimensions of image
      int ni, nj;
      input>>ni>>nj;
      std::cout<<" - dimensions: "<<ni<<" x "<<nj<<std::endl;
      // initialize the RGB buffer (img) and the Z buffer (zbuffer)
      Array2<Vec3f> img(ni, nj, Vec3f(0,0,0));
      Array2f zbuffer(ni, nj, 1);
      // rasterize all the triangles in the input file
      while(input){
         if(!input) break; // nothing more to read
         Vec3f color0, color1, color2;
         Vec3f x0, x1, x2;
         input>>color0>>x0>>color1>>x1>>color2>>x2;
         rasterize_triangle(img, zbuffer, color0, x0, color1, x1, color2, x2);
      }
      // write out the image
      std::cout<<" - finished rasterization"<<std::endl;
      write_sgi_compressed(img, "%s", image_filename.c_str());
   }
   return 0;
}

